@@ -4,7 +4,7 @@ from async_asgi_testclient import TestClient
 
 from nextlinegraphql import create_app
 
-from ..gql import QUERY_SOURCE, MUTATION_RESET
+from ..graphql import QUERY_SOURCE, MUTATE_RESET
 
 ##__________________________________________________________________||
 SOURCE_ONE = """
@@ -25,7 +25,7 @@ async def test_reset(snapshot, statement):
 
     headers = {"Content-Type:": "application/json"}
 
-    data = {"query": MUTATION_RESET}
+    data = {"query": MUTATE_RESET}
     if statement:
         data["variables"] = {"statement": statement}
 
@@ -34,9 +34,8 @@ async def test_reset(snapshot, statement):
         assert resp.status_code == 200
         assert {"data": {"reset": True}} == resp.json()
 
-    data = {"query": QUERY_SOURCE}
+        data = {"query": QUERY_SOURCE}
 
-    async with TestClient(create_app()) as client:
         resp = await client.post("/", json=data, headers=headers)
         assert resp.status_code == 200
         snapshot.assert_match(resp.json())
